@@ -118,57 +118,57 @@ struct osmtpd_ctx {
 };
 
 void osmtpd_register_conf(void (*)(const char *, const char *));
-void osmtpd_register_filter_connect(void (*)(struct osmtpd_ctx *, const char *,
+void osmtpd_register_filter_connect(int (*)(struct osmtpd_ctx *, const char *,
     struct sockaddr_storage *));
-void osmtpd_register_filter_helo(void (*)(struct osmtpd_ctx *, const char *));
-void osmtpd_register_filter_ehlo(void (*)(struct osmtpd_ctx *, const char *));
-void osmtpd_register_filter_starttls(void (*)(struct osmtpd_ctx *));
-void osmtpd_register_filter_auth(void (*)(struct osmtpd_ctx *, const char *));
-void osmtpd_register_filter_mailfrom(void (*)(struct osmtpd_ctx *,
+void osmtpd_register_filter_helo(int (*)(struct osmtpd_ctx *, const char *));
+void osmtpd_register_filter_ehlo(int (*)(struct osmtpd_ctx *, const char *));
+void osmtpd_register_filter_starttls(int (*)(struct osmtpd_ctx *));
+void osmtpd_register_filter_auth(int (*)(struct osmtpd_ctx *, const char *));
+void osmtpd_register_filter_mailfrom(int (*)(struct osmtpd_ctx *,
     const char *));
-void osmtpd_register_filter_rcptto(void (*)(struct osmtpd_ctx *, const char *));
-void osmtpd_register_filter_data(void (*)(struct osmtpd_ctx *));
-void osmtpd_register_filter_dataline(void (*)(struct osmtpd_ctx *,
+void osmtpd_register_filter_rcptto(int (*)(struct osmtpd_ctx *, const char *));
+void osmtpd_register_filter_data(int (*)(struct osmtpd_ctx *));
+void osmtpd_register_filter_dataline(int (*)(struct osmtpd_ctx *,
     const char *));
-void osmtpd_register_filter_rset(void (*)(struct osmtpd_ctx *));
-void osmtpd_register_filter_quit(void (*)(struct osmtpd_ctx *));
-void osmtpd_register_filter_noop(void (*)(struct osmtpd_ctx *));
-void osmtpd_register_filter_help(void (*)(struct osmtpd_ctx *));
-void osmtpd_register_filter_wiz(void (*)(struct osmtpd_ctx *));
-void osmtpd_register_filter_commit(void (*)(struct osmtpd_ctx *));
-void osmtpd_register_report_connect(int, void (*)(struct osmtpd_ctx *,
+void osmtpd_register_filter_rset(int (*)(struct osmtpd_ctx *));
+void osmtpd_register_filter_quit(int (*)(struct osmtpd_ctx *));
+void osmtpd_register_filter_noop(int (*)(struct osmtpd_ctx *));
+void osmtpd_register_filter_help(int (*)(struct osmtpd_ctx *));
+void osmtpd_register_filter_wiz(int (*)(struct osmtpd_ctx *));
+void osmtpd_register_filter_commit(int (*)(struct osmtpd_ctx *));
+void osmtpd_register_report_connect(int, int (*)(struct osmtpd_ctx *,
     const char *, enum osmtpd_status, struct sockaddr_storage *,
     struct sockaddr_storage *));
-void osmtpd_register_report_disconnect(int, void (*)(struct osmtpd_ctx *));
-void osmtpd_register_report_greeting(int, void (*)(struct osmtpd_ctx *,
+void osmtpd_register_report_disconnect(int, int (*)(struct osmtpd_ctx *));
+void osmtpd_register_report_greeting(int, int (*)(struct osmtpd_ctx *,
     const char *));
-void osmtpd_register_report_identify(int, void (*)(struct osmtpd_ctx *,
+void osmtpd_register_report_identify(int, int (*)(struct osmtpd_ctx *,
     const char *));
-void osmtpd_register_report_tls(int, void (*)(struct osmtpd_ctx *,
+void osmtpd_register_report_tls(int, int (*)(struct osmtpd_ctx *,
     const char *));
-void osmtpd_register_report_auth(int, void (*)(struct osmtpd_ctx *,
+void osmtpd_register_report_auth(int, int (*)(struct osmtpd_ctx *,
     const char *, enum osmtpd_auth_status));
-void osmtpd_register_report_reset(int, void (*)(struct osmtpd_ctx *, uint32_t));
-void osmtpd_register_report_begin(int, void (*)(struct osmtpd_ctx *, uint32_t));
-void osmtpd_register_report_mail(int, void (*)(struct osmtpd_ctx *, uint32_t,
+void osmtpd_register_report_reset(int, int (*)(struct osmtpd_ctx *, uint32_t));
+void osmtpd_register_report_begin(int, int (*)(struct osmtpd_ctx *, uint32_t));
+void osmtpd_register_report_mail(int, int (*)(struct osmtpd_ctx *, uint32_t,
     const char *, enum osmtpd_status));
-void osmtpd_register_report_rcpt(int, void (*)(struct osmtpd_ctx *, uint32_t,
+void osmtpd_register_report_rcpt(int, int (*)(struct osmtpd_ctx *, uint32_t,
     const char *, enum osmtpd_status));
-void osmtpd_register_report_envelope(int, void (*)(struct osmtpd_ctx *, uint32_t,
+void osmtpd_register_report_envelope(int, int (*)(struct osmtpd_ctx *, uint32_t,
     uint64_t));
-void osmtpd_register_report_data(int, void (*)(struct osmtpd_ctx *, uint32_t,
+void osmtpd_register_report_data(int, int (*)(struct osmtpd_ctx *, uint32_t,
     enum osmtpd_status));
-void osmtpd_register_report_commit(int, void (*)(struct osmtpd_ctx *, uint32_t,
+void osmtpd_register_report_commit(int, int (*)(struct osmtpd_ctx *, uint32_t,
     size_t));
-void osmtpd_register_report_rollback(int, void (*)(struct osmtpd_ctx *,
+void osmtpd_register_report_rollback(int, int (*)(struct osmtpd_ctx *,
     uint32_t));
-void osmtpd_register_report_client(int, void (*)(struct osmtpd_ctx *,
+void osmtpd_register_report_client(int, int (*)(struct osmtpd_ctx *,
     const char *));
-void osmtpd_register_report_server(int, void (*)(struct osmtpd_ctx *,
+void osmtpd_register_report_server(int, int (*)(struct osmtpd_ctx *,
     const char *));
-void osmtpd_register_report_response(int, void (*)(struct osmtpd_ctx *,
+void osmtpd_register_report_response(int, int (*)(struct osmtpd_ctx *,
     const char *));
-void osmtpd_register_report_timeout(int, void (*)(struct osmtpd_ctx *));
+void osmtpd_register_report_timeout(int, int (*)(struct osmtpd_ctx *));
 void osmtpd_local_session(void *(*)(struct osmtpd_ctx *),
     void (*)(struct osmtpd_ctx *, void *));
 void osmtpd_local_message(void *(*)(struct osmtpd_ctx *),
